@@ -223,12 +223,17 @@ class ReAct(Module):
             else {"answer": "string"}
         )
 
+        # Better instructions for extraction that understand the trajectory
+        extract_instructions = (
+            "Given the trajectory of reasoning and tool use, extract the final answer to the original problem. "
+            "Look for the key result that answers the question, not intermediate calculations or checks. "
+            "If the problem asks 'how much do I earn' and the calculation shows 200, the answer is '$200' or '200 dollars'."
+        )
+        
         self.fallback_signature = BaseSignature(
             input_fields=fallback_inputs,
             output_fields=fallback_outputs,
-            instructions=self.original_signature.instructions
-            if self.original_signature
-            else "Extract the final answer.",
+            instructions=extract_instructions,
         )
         self.fallback_signature.input_fields["trajectory"] = "string"  # Add trajectory input
 
